@@ -19,10 +19,10 @@
 #ifndef __kbookmarkmanager_h
 #define __kbookmarkmanager_h
 
-#include <QtCore/QString>
-#include <QtCore/QObject>
-#include <QtXml/QDomDocument>
-#include <QtXml/QDomElement>
+#include <QString>
+#include <QObject>
+#include <QDomDocument>
+#include <QDomElement>
 class KBookmarkManagerPrivate;
 
 #include "kbookmark.h"
@@ -113,7 +113,7 @@ public:
     * error occurs. It is turned on by default.
     * If disabled, the application should react on the error() signal.
     * @param enable true to enable auto error handling, false to disable
-    * @param parent the parent widget for the error dialogs, can be 0 for
+    * @param parent the parent widget for the error dialogs, can be @c nullptr for
     *               top-level
     * @since 4.6
     * @see autoErrorHandlingEnabled()
